pub struct W(/* private fields */);Expand description
Register EXTTRACECMD writer
Implementations
Sourceimpl W
impl W
Sourcepub fn start(&mut self) -> START_W<'_>
pub fn start(&mut self) -> START_W<'_>
Bit 0 - Trace start command. Writing a one to this bit sets the TSTART signal to the MTB to HIGH and starts tracing if the TSTARTEN bit in the MTB master register is set to one as well.
Methods from Deref<Target = W<EXTTRACECMD_SPEC>>